@@ -1,3 +1,7 @@
+from eloquentarduino.ml.classification.tensorflow.pickle_patch import make_keras_picklable
+
+make_keras_picklable()
+
 from eloquentarduino.ml.classification.tensorflow.Layer import Layer, layers
 from eloquentarduino.ml.classification.tensorflow.NeuralNetwork import NeuralNetwork
-from eloquentarduino.ml.classification.tensorflow.GridSearch import GridSearch
+from eloquentarduino.ml.classification.tensorflow.GridSearch import GridSearch
\ No newline at end of file
