@@ -50,6 +50,7 @@ class Dataset(LoadsDatasetMixin, DropsTimeSeriesOutliersMixin, PlotsItselfMixin)
 
         self.columns = columns
         self.classmap = classmap or {-1: 'UNLABELLED'}
+        self.outlier_class = None
 
     def __getitem__(self, item):
         """
@@ -115,6 +116,17 @@ class Dataset(LoadsDatasetMixin, DropsTimeSeriesOutliersMixin, PlotsItselfMixin)
         # account for one-hot encoding
         return len(self.labels) if len(self.y.shape) == 1 else self.y.shape[1]
 
+    @property
+    def next_class(self):
+        """
+        Get next class idx
+        :return: int
+        """
+        next_class_by_classmap = max(self.classmap.keys()) + 1
+        next_class_by_labels = np.max(self.y) + 1
+
+        return max(next_class_by_classmap, next_class_by_labels)
+
     @property
     def shape(self):
         """
@@ -211,10 +223,9 @@ class Dataset(LoadsDatasetMixin, DropsTimeSeriesOutliersMixin, PlotsItselfMixin)
         """
         class_idx = self._get_label_id(class_idx)
         mask = (self.y != class_idx)
-        print('drop_class', class_idx)
-        print('dropping...', (~mask).sum())
+        new_classmap = {k: v for k, v in self.classmap.items() if k != class_idx}
 
-        return self.mask(mask)
+        return self.mask(mask).replace(classmap=new_classmap)
 
     def drop_out_of_classmap(self):
         """
@@ -322,6 +333,9 @@ class Dataset(LoadsDatasetMixin, DropsTimeSeriesOutliersMixin, PlotsItselfMixin)
         if columns is None:
             columns = self.columns
 
+        if columns is not None and len(columns) != X.shape[1]:
+            columns = ['f%d' % i for i in range(X.shape[1])]
+
         if name is None:
             name = self.name
 
