@@ -135,9 +135,16 @@ class LoadsDatasetMixin:
         """
         Create the Iris dataset
         """
-        return cls('Iris', *load_iris(return_X_y=True))
+        return cls('Iris', *load_iris(return_X_y=True), classmap={0: 'setosa', 1: 'versicolor', 2: 'virginica'})
 
-    @staticmethod
+    @classmethod
+    def MNIST(cls):
+        """
+        Create the Iris dataset
+        """
+        return cls('MNIST', *load_digits(return_X_y=True))
+
+    @classmethod
     def MNIST_Tensorflow(cls):
         """
         Create the MNIST dataset formatted for Tensorflow
