@@ -62,11 +62,30 @@ class PlotsItselfMixin:
         run_values = y[loc_run_start]
         palette = [c for c in (palette or mcolors.TABLEAU_COLORS.values())]
 
+        if self.outlier_class:
+            palette[self.outlier_class % len(palette)] = '#2c3e50'
+
         if self.y.max() >= len(palette):
             print('[WARN] too many classes for the current palette')
 
+        vspan_handles = {}
+
         for v, s, l in zip(run_values, run_starts, run_lengths):
-            plt.axvspan(s, s + l, color=palette[v % len(palette)], alpha=bg_alpha)
+            if v in vspan_handles:
+                vspan_label = '_ignore'
+            else:
+                vspan_handles.setdefault(v, True)
+                vspan_label = self.classmap.get(v % len(palette), 'Class #%d' % (v % len(palette)))
+
+            plt.axvspan(
+                s,
+                s + l,
+                color=palette[v % len(palette)],
+                alpha=(bg_alpha * 1.25 if palette[v % len(palette)] == '#2c3e50' else bg_alpha),
+                label=vspan_label
+            )
+
+        plt.legend()
 
         # plot y_test markers
         if y_pred is not None:
@@ -184,6 +203,27 @@ class PlotsItselfMixin:
 
         sns.pairplot(df.astype({'y': 'int'}), hue='y', palette=palette, **kwargs)
 
+    def plot_boxplot(self, features_per_row=10):
+        """
+        Draw box plot of features vs class
+        :param features_per_row: int in the presence of lots of features, split plots
+        """
+        df = self.df
+
+        for k in range(0, len(df.columns), features_per_row):
+            columns = df.columns[k:k + features_per_row]
+            rows = [{
+                'feature_name': column,
+                'value': value,
+                'y': str(self.classmap.get(self.y[i], self.y[i]))
+            } for column, values in df[columns].iteritems() if column != 'y' for i, value in enumerate(values)]
+
+            df_k = pd.DataFrame(rows)
+
+            if len(df_k.columns) > 0:
+                plt.figure()
+                sns.boxplot(data=df_k, x="feature_name", y="value", hue="y", orient="v")
+
     def dim_reduction(self, pca=0, tsne=0, umap=0, isomap=0, lle=0, lda=False, **kwargs):
         """
         Apply dimensionality reduction
@@ -243,8 +283,8 @@ class PlotsItselfMixin:
         """
         max_length = max_length or 0
 
-        if max_length > 0 and len(array) > max_length:
-            idx = (np.arange(max_length, dtype=float) * len(array) / max_length)
+        if 0 < max_length < len(array):
+            idx = np.arange(max_length, dtype=float) * (len(array) / max_length)
             idx = np.unique(idx.astype(int))
 
             return idx
